@@ -53,13 +53,29 @@ spec.mtm <- function(timeSeries,
                      sineAdaptive=FALSE,
                      sineSmoothFact=0.2,
                      dtUnits=c("default"),
-                     dT=NULL,
+                     deltat=NULL,
                      ...) {
     
     series <- deparse(substitute(timeSeries))
     taper <- match.arg(taper,c("dpss","sine"))
     centre <- match.arg(centre,c("Slepian","arithMean","trimMean","none"))
     dtUnits <- match.arg(dtUnits,c("second","hour","day","month","year","default"))
+
+    ## deal with depreciated parameter dT is changed to deltat
+    ## we strip dT before plotting in plotsHelper.R
+    ## to prevent it getting passed to plot
+ 
+    deltaT <- NULL
+    if(!missing(deltat)) {
+        deltaT <- deltat
+    }
+   
+    dT <- list(...)$dT
+    
+    if(missing(deltat) && !is.null(dT)) {
+        warning("dT has been depreciated. Use either deltat or input a time series object.")
+        deltaT <- dT
+    }
     
     if( (taper=="sine") && is.complex(timeSeries)) {
         stop("Sine tapering not implemented for complex time series.") 
@@ -82,8 +98,8 @@ spec.mtm <- function(timeSeries,
     
     dtTmp <- NULL
     ## warning for deltaT missing: makes all frequency plots incorrect
-    if(!is.ts(timeSeries) && is.null(dT)) {
-        warning("Time series is not a ts object and dT is not set. Frequency array and axes may be incorrect.")
+    if(!is.ts(timeSeries) && is.null(deltaT)) {
+        warning("Time series is not a ts object and deltat is not set. Frequency array and axes may be incorrect.")
     }
     if(!is.ts(timeSeries)) {
         if(!is.complex(timeSeries)) {
@@ -98,11 +114,9 @@ spec.mtm <- function(timeSeries,
     }
     
     ## in responese to delta T bug July 2, 2013
+    ## modified to remove dT
     
-    deltaT <- NULL
-    if(!is.null(dT)) {
-        deltaT <- dT
-    } else {
+    if(is.null(deltaT)) {
         if(!is.null(dtTmp)) {
             deltaT <- dtTmp
         } else{
@@ -362,7 +376,7 @@ spec.mtm <- function(timeSeries,
     if(Ftest) {
         class(spec.out) <- c("mtm", "Ftest", "spec")
     }
-    return(spec.out);
+    return(spec.out)
 }
 
 
@@ -493,7 +507,7 @@ spec.mtm <- function(timeSeries,
                      mtm=auxiliary)
 
     class(spec.out) <- c("mtm", "spec")
-    return(spec.out);
+    return(spec.out)
 }
 
 #########################################################################
@@ -523,7 +537,7 @@ centre <- function(x, nw=NULL, k=NULL, deltaT=NULL, trim=0) {
                 deltaT <- deltat(ts)
             } else {
                 warning("deltaT not specified; using deltaT=1.")
-                deltaT <- 1
+                deltaT <- 1.0
             }
         }
         n <- length(x)
